@@ -1,5 +1,6 @@
 #!/usr/bin/python3
 
+from unidecode import unidecode
 from subprocess import Popen, PIPE
 import getopt
 import gettext
@@ -37,6 +38,10 @@ _ = gettext.gettext
 # https://technet.microsoft.com/en-us/library/bb490925.aspx
 FORBIDDEN_CHARS = ["*", "?", "/", "\\", "|", ".", ",", ";", ":", "+", "=", "[", "]", "<", ">", "\""]
 
+RELEVANT_UDISK_PROPERTIES = ['connection-bus', 'ejectable', 'id', \
+'media-available', 'media-compatibility', 'media-removable', \
+'model', 'vendor', 'optical', 'removable', 'size']
+
 # noinspection PyUnusedLocal
 class MintStick:
     def __init__(self, iso_path_arg=None, usb_path_arg=None, filesystem_arg=None, mode_arg=None, debug_arg=False):
@@ -107,6 +112,10 @@ class MintStick:
             self.devicelist = self.wTree.get_object("formatdevice_combobox")
             self.go_button = self.wTree.get_object("format_formatbutton")
             self.label_entry = self.wTree.get_object("volume_label_entry")
+            try:
+                self.label_entry.set_text(unidecode(self.label_entry.get_text()))
+            except:
+                self.label_entry.set_text("USB STICK")
             self.label_entry_changed_id = self.label_entry.connect("changed", self.on_label_entry_text_changed)
 
             self.window = self.wTree.get_object("format_window")
@@ -168,10 +177,22 @@ class MintStick:
     def verify(self, button):
         subprocess.Popen(["mint-iso-verify", self.chooser.get_filename()])
 
+    def print_drive(self, drive):
+        # print drive info to stdout
+        # this is done for debugging purposes
+        try:
+            for prop in drive.list_properties():
+                name = prop.name
+                if name in RELEVANT_UDISK_PROPERTIES:
+                    print(f"    {prop.name}: {drive.get_property(prop.name)}")
+            print()
+        except Exception as e:
+            print(e)
+
     def get_devices(self):
         self.go_button.set_sensitive(False)
         self.devicemodel.clear()
-        dct = []
+        detected_drives = []
         self.dev = None
 
         manager = self.udisks_client.get_object_manager()
@@ -182,7 +203,12 @@ class MintStick:
                 if block is not None:
                     drive = self.udisks_client.get_drive_for_block(block)
                     if drive is not None:
-                        is_usb = str(drive.get_property('connection-bus')) in ['usb', 'cpio']
+                        drive_id = drive.get_property('id')
+                        if drive_id in detected_drives:
+                            continue
+                        detected_drives.append(drive_id)
+                        self.print_drive(drive)
+                        is_usb = str(drive.get_property('connection-bus')) in ['usb', 'cpio', 'sdio']
                         size = int(drive.get_property('size'))
                         optical = bool(drive.get_property('optical'))
                         removable = bool(drive.get_property('removable'))
@@ -210,9 +236,7 @@ class MintStick:
 
                             item = "%s (%s) - %s" % (drive_model, name, size)
 
-                            if item not in dct:
-                                dct.append(item)
-                                self.devicemodel.append([name, item])
+                            self.devicemodel.append([name, item])
 
         self.devicelist.set_model(self.devicemodel)
 
@@ -246,19 +270,23 @@ class MintStick:
         value = self.fsmodel.get_value(active_iter, 0)
         cursor_pos = self.label_entry.props.cursor_position
 
+        text = self.label_entry.get_text()
+
         if self.fsmodel.get_value(active_iter, 3):
-            old_text = self.label_entry.get_text()
-            new_text = old_text.upper()
-            self.label_entry.set_text(new_text)
+            text = text.upper()
 
         if self.fsmodel.get_value(active_iter, 4):
-            old_text = self.label_entry.get_text()
-
             for char in FORBIDDEN_CHARS:
-                old_text = old_text.replace(char, "")
+                text = text.replace(char, "")
+        try:
+            text = unidecode(text)
+        except Exception as e:
+            print(f"Exception in sanitizing the label {text}")
+            print(str(e))
+            text = "USB STICK"
 
-            new_text = old_text
-            self.label_entry.set_text(new_text)
+        self.label_entry.set_text(text)
+        self.go_button.set_sensitive(len(text) > 0)
 
         length = self.label_entry.get_buffer().get_length()
         self.label_entry.select_region(length, -1)
@@ -471,6 +499,7 @@ class MintStick:
             self.get_devices()
         self.filesystemlist.set_sensitive(True)
         self.devicelist.set_sensitive(True)
+        self.label_entry.set_sensitive(True)
         self.go_button.set_sensitive(True)
 
 if __name__ == "__main__":
