@@ -81,8 +81,9 @@ class App():
         self.builder.get_object("verify_checksum_button").connect("clicked", self.verify_checksum)
         self.builder.get_object("back_button").connect("clicked", self.go_back)
         self.builder.get_object("stack_checksum").connect("notify::visible-child-name", self.update_verify_button)
+        self.builder.get_object("entry_sum").connect("changed", self.update_verify_button)
 
-        # filechooser filters
+        # filechoosers
         file_filter = Gtk.FileFilter()
         file_filter.set_name(_("ISO images"))
         file_filter.add_mime_type("application/x-cd-image")
@@ -98,6 +99,9 @@ class App():
         file_filter.add_mime_type("application/pgp-keys")
         self.builder.get_object("filechooser_gpg").add_filter(file_filter)
 
+        self.builder.get_object("filechooser_sums").connect("file-set", self.update_verify_button)
+        self.builder.get_object("filechooser_gpg").connect("file-set", self.update_verify_button)
+
 
     def file_selected(self, widget=None):
         self.path = None
@@ -190,23 +194,21 @@ class App():
         self.sha256sum = checksum
 
     def update_verify_button(self, *args):
+        self.builder.get_object("verify_url_button").set_sensitive(False)
         self.builder.get_object("verify_files_button").set_sensitive(False)
         self.builder.get_object("verify_checksum_button").set_sensitive(False)
 
         if self.sha256sum is None:
             return
 
-        current_page = self.builder.get_object("stack_checksum").get_visible_child_name()
+        if self.builder.get_object("entry_url_sums").get_text() != "" and self.builder.get_object("entry_url_gpg").get_text() != "":
+            self.builder.get_object("verify_url_button").set_sensitive(True)
 
-        if current_page == "page_url":
-            if self.builder.get_object("entry_url_sums").get_text() != "" and self.builder.get_object("entry_url_gpg").get_text() != "":
-                self.builder.get_object("verify_url_button").set_sensitive(True)
-        elif current_page == "page_files":
-            if self.builder.get_object("filechooser_sums").get_filename() is not None and self.builder.get_object("filechooser_gpg").get_filename() is not None:
-                self.builder.get_object("verify_files_button").set_sensitive(True)
-        elif current_page == "page_sum_manual":
-            if (self.builder.get_object("entry_sum").get_text() != ""):
-                self.builder.get_object("verify_checksum_button").set_sensitive(True)
+        if self.builder.get_object("filechooser_sums").get_filename() is not None and self.builder.get_object("filechooser_gpg").get_filename() is not None:
+            self.builder.get_object("verify_files_button").set_sensitive(True)
+
+        if (self.builder.get_object("entry_sum").get_text() != ""):
+            self.builder.get_object("verify_checksum_button").set_sensitive(True)
 
     @idle_function
     def set_label(self, label, text):
@@ -214,7 +216,7 @@ class App():
         self.update_verify_button()
 
     def verify_checksum(self, button):
-        if self.builder.get_object("entry_sum").get_text() == self.sha256sum:
+        if self.builder.get_object("entry_sum").get_text().lower() == self.sha256sum.lower():
             self.show_result("dialog-warning", _("The checksum is correct"),
                     summary=_("The checksum is correct but the authenticity of the sum was not verified."))
         else:
